pub struct GetExecutionParams {
pub symbol: Option<String>,
pub filter: Option<Value>,
pub columns: Option<Value>,
pub count: Option<i32>,
pub start: Option<i32>,
pub reverse: Option<bool>,
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
}Expand description
Parameters for the GET /execution/tradeHistory endpoint.
Fields
symbol: Option<String>Instrument symbol. Send a bare series (e.g. XBT) to get data for the nearest expiring contract in that series. You can also send a timeframe, e.g. XBT:quarterly. Timeframes are nearest, daily, weekly, monthly, quarterly, biquarterly, and perpetual.
filter: Option<Value>Generic table filter. Send JSON key/value pairs, such as {"key": "value"}. You can key on individual fields, and do more advanced querying on timestamps. See the Timestamp Docs for more details.
columns: Option<Value>Array of column names to fetch. If omitted, will return all columns. Note that this method will always return item keys, even when not specified, so you may receive more columns that you expect.
count: Option<i32>Number of results to fetch.
start: Option<i32>Starting point for results.
reverse: Option<bool>If true, will sort results newest first.
start_time: Option<Timestamp>Starting date filter for results.
end_time: Option<Timestamp>Ending date filter for results.